# EduKTM
[![PyPI](https://img.shields.io/pypi/v/EduKTM.svg)](https://pypi.python.org/pypi/EduKTM)
[![Build Status](https://www.travis-ci.org/bigdata-ustc/EduKTM.svg?branch=main)](https://www.travis-ci.org/bigdata-ustc/EduKTM)
[![codecov](https://codecov.io/gh/bigdata-ustc/EduKTM/branch/main/graph/badge.svg?token=B7gscOGQLD)](https://codecov.io/gh/bigdata-ustc/EduKTM)
[![Download](https://img.shields.io/pypi/dm/EduKTM.svg?style=flat)](https://pypi.python.org/pypi/EduKTM)

The Model Zoo of Knowledge Tracing  Models
